==> haskell-gi-0.25.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi
version:              0.25.0
visibility:           public
id:                   haskell-gi-0.25.0-6r0XAG2m9adDsqmHMXXvyo
key:                  haskell-gi-0.25.0-6r0XAG2m9adDsqmHMXXvyo
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (inaki@blueleaf.cc)
author:
    Will Thompson,
    Iñaki García Etxebarria,
    Jonas Platte

stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    Gtk+, but many other libraries in the GObject ecosystem provide introspection data too.

category:             Development
abi:                  b12e675dd1271fd3c82ef560bf746e0b
exposed:              True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.Cabal
    Data.GI.CodeGen.CabalHooks Data.GI.CodeGen.Callable
    Data.GI.CodeGen.Code Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedMethods Data.GI.CodeGen.OverloadedSignals
    Data.GI.CodeGen.Overrides Data.GI.CodeGen.PkgConfig
    Data.GI.CodeGen.ProjectInfo Data.GI.CodeGen.Properties
    Data.GI.CodeGen.Signal Data.GI.CodeGen.Struct
    Data.GI.CodeGen.SymbolNaming Data.GI.CodeGen.Transfer
    Data.GI.CodeGen.Type Data.GI.CodeGen.Util Data.GI.GIR.Alias
    Data.GI.GIR.Allocation Data.GI.GIR.Arg Data.GI.GIR.BasicTypes
    Data.GI.GIR.Callable Data.GI.GIR.Callback Data.GI.GIR.Constant
    Data.GI.GIR.Deprecation Data.GI.GIR.Documentation Data.GI.GIR.Enum
    Data.GI.GIR.Field Data.GI.GIR.Flags Data.GI.GIR.Function
    Data.GI.GIR.Interface Data.GI.GIR.Method Data.GI.GIR.Object
    Data.GI.GIR.Parser Data.GI.GIR.Property Data.GI.GIR.Repository
    Data.GI.GIR.Signal Data.GI.GIR.Struct Data.GI.GIR.Type
    Data.GI.GIR.Union Data.GI.GIR.XMLUtils

hidden-modules:       Paths_haskell_gi
import-dirs:          /usr/lib/ghc-9.0.1/site-local/haskell-gi-0.25.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/haskell-gi-0.25.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/haskell-gi-0.25.0
hs-libraries:         HShaskell-gi-0.25.0-6r0XAG2m9adDsqmHMXXvyo
extra-libraries:      girepository-1.0 gobject-2.0 glib-2.0
include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include

depends:
    Cabal-3.4.0.0 ansi-terminal-0.11-Kvq5JBN7BE16HA1JfrRBzw
    attoparsec-0.14.1-2NPvvgp5QbjKeCRmapAgpC base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.1
    filepath-1.4.2.1 haskell-gi-base-0.25.0-EPjyZHXH1O71iu9csuFFc
    mtl-2.2.2 pretty-show-1.10-G4SfLXvOfw8HasEUHDrqxD process-1.6.11.0
    regex-tdfa-1.3.1.1-8KBKH3EsotI2v3BWqoG8PB
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj text-1.2.4.1
    transformers-0.5.6.2 xdg-basedir-0.2.2-FxvLd0PtCIDHWciCXDjKP6
    xml-conduit-1.9.1.1-6pgp6KEeQtY9ZzjKhWpcJ6

haddock-interfaces:   /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:         /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-0.25.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi
version:              0.25.0
visibility:           public
id:                   haskell-gi-0.25.0-GdkYp4XjoJDJQ1kgRuodMi
key:                  haskell-gi-0.25.0-GdkYp4XjoJDJQ1kgRuodMi
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (inaki@blueleaf.cc)
author:
    Will Thompson,
    Iñaki García Etxebarria,
    Jonas Platte

stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    Gtk+, but many other libraries in the GObject ecosystem provide introspection data too.

category:             Development
abi:                  e0d495131901a75dbf4ee84b6b55898e
exposed:              True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.Cabal
    Data.GI.CodeGen.CabalHooks Data.GI.CodeGen.Callable
    Data.GI.CodeGen.Code Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedMethods Data.GI.CodeGen.OverloadedSignals
    Data.GI.CodeGen.Overrides Data.GI.CodeGen.PkgConfig
    Data.GI.CodeGen.ProjectInfo Data.GI.CodeGen.Properties
    Data.GI.CodeGen.Signal Data.GI.CodeGen.Struct
    Data.GI.CodeGen.SymbolNaming Data.GI.CodeGen.Transfer
    Data.GI.CodeGen.Type Data.GI.CodeGen.Util Data.GI.GIR.Alias
    Data.GI.GIR.Allocation Data.GI.GIR.Arg Data.GI.GIR.BasicTypes
    Data.GI.GIR.Callable Data.GI.GIR.Callback Data.GI.GIR.Constant
    Data.GI.GIR.Deprecation Data.GI.GIR.Documentation Data.GI.GIR.Enum
    Data.GI.GIR.Field Data.GI.GIR.Flags Data.GI.GIR.Function
    Data.GI.GIR.Interface Data.GI.GIR.Method Data.GI.GIR.Object
    Data.GI.GIR.Parser Data.GI.GIR.Property Data.GI.GIR.Repository
    Data.GI.GIR.Signal Data.GI.GIR.Struct Data.GI.GIR.Type
    Data.GI.GIR.Union Data.GI.GIR.XMLUtils

hidden-modules:       Paths_haskell_gi
import-dirs:          /usr/lib/ghc-9.0.1/site-local/haskell-gi-0.25.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/haskell-gi-0.25.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/haskell-gi-0.25.0
hs-libraries:         HShaskell-gi-0.25.0-GdkYp4XjoJDJQ1kgRuodMi
extra-libraries:      girepository-1.0 gobject-2.0 glib-2.0
include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include

depends:
    Cabal-3.4.0.0 ansi-terminal-0.11-DOUngjGM5e9DBdxKKdJoVq
    attoparsec-0.14.1-B8P567zH1pOF107V9enGUK base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.1
    filepath-1.4.2.1 haskell-gi-base-0.25.0-EPjyZHXH1O71iu9csuFFc
    mtl-2.2.2 pretty-show-1.10-G4SfLXvOfw8HasEUHDrqxD process-1.6.11.0
    regex-tdfa-1.3.1.1-JysT5HHQf7SDqagoTfdJw
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj text-1.2.4.1
    transformers-0.5.6.2 xdg-basedir-0.2.2-FxvLd0PtCIDHWciCXDjKP6
    xml-conduit-1.9.1.1-8szrhDccdR56PHnyZ5pHlE

haddock-interfaces:   /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:         /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
